@@ -21,12 +21,29 @@
 # SOFTWARE.
 
 """
-`loggingpython`
+This module defines a custom exception class `ServerMethodCallError` for
+handling errors related to the incorrect calling of server-specific methods on
+the client side. This exception is part of the `loggingpython` package,
+designed to ensure that server-side methods are not mistakenly invoked on the
+client, which could lead to incorrect behavior or security vulnerabilities.
 
-Raised when a method intended for the server is called on the client.
-This error indicates that a method that should only be executed by the
-server was mistakenly called by the client, which could lead to incorrect
-behavior.
+The `ServerMethodCallError` class inherits from the built-in `Exception`
+class, allowing it to be raised and caught like any other exception. It takes
+an optional message parameter that defaults to "This method can only be called
+by the server." This message is passed to the base class constructor to
+provide a descriptive error message when the exception is raised.
+
+Example usage:
+
+    try:
+        # Attempt to call a server-specific method on the client
+        some_client_method()
+    except ServerMethodCallError as e:
+        print(f"Error: {e}")
+
+This module is part of the `loggingpython` package, which aims to provide a
+comprehensive logging solution for Python applications, including error
+handling and logging mechanisms for both client and server-side operations.
 """
 
 
